﻿;==============================================================================================================================================================================
; Write the error log to disk every 50 entries
;=============================================================================================================================================================================

Procedure WriteError(Flag.i, ModuleName.s = "", Message.s = "", ExtraInfo.s = "")
  
  ;------------------------------------------------------------------------------------------------
  ; First time this has run for the current session so create a new log file, overwrite the old one
  ;------------------------------------------------------------------------------------------------
  
  If Program\ErrorLogExists = #False And ListSize(Error()) <> #False
    
    ;----------------------------------------------------------------------------------------------
    ; Set the flag to prevent the file creation and header addition again
    ;----------------------------------------------------------------------------------------------
    
    Program\ErrorLogExists = #True
    
    ;----------------------------------------------------------------------------------------------
    ; Setup the formatted date value or the header
    ;----------------------------------------------------------------------------------------------
    
    DateVal       = Date()
    
    CurrentDate.s = NameOfDay(DayOfWeek(DateVal))    + " "
    
    CurrentDate.s + Str(Day(DateVal))                + " "
    
    CurrentDate.s + NameOfMonth(Month(DateVal) - 1)  + " "
    
    CurrentDate.s + Str(Year(DateVal))
    
    ;----------------------------------------------------------------------------------------------
    ; Try to create the file now
    ;----------------------------------------------------------------------------------------------
    
    LogFileId.i = CreateFile(#PB_Any, Program\ErrorFile)
    
    ;----------------------------------------------------------------------------------------------
    ; If we got a file handle, write the header details to it
    ;----------------------------------------------------------------------------------------------
    
    If LogFileId.i
      
      FileSeek(LogFileId.i, Lof(LogFileId.i))
      
      WriteStringN(LogFileId.i, "----------------------------------------------------------------------")
      
      WriteStringN(LogFileId.i, "New " + #BaseName + #Version + " program run,  " + CurrentDate.s)
      
      WriteStringN(LogFileId.i, "----------------------------------------------------------------------")
      
      CloseFile(LogFileId.i)
      
    Else
      
      ; SetInfoBarArea("Headings", "Error",  "We could not get a file id after creation so we should exit at this point", #PB_Compiler_Procedure)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    ; SetInfoBarArea("Headings", "Error", "File is already created this run and the header has been added", #PB_Compiler_Procedure)
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; Errors are ready to be written to the file if list is full or routine is called at program end
  ;------------------------------------------------------------------------------------------------
  
  If ListSize(Error()) > 50 Or Flag.i = #True
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the previously created error log file
    ;----------------------------------------------------------------------------------------------
    
    LogFileId.i = OpenFile(#PB_Any, Program\ErrorFile)
    
    ;----------------------------------------------------------------------------------------------
    ; Now let's see if we got a file handle
    ;----------------------------------------------------------------------------------------------
    
    If LogFileId.i
      
      ;--------------------------------------------------------------------------------------------
      ; Seek to the end of the file to add entries
      ;--------------------------------------------------------------------------------------------
      
      FileSeek(LogFileId.i, Lof(LogFileId.i))
      
      ;--------------------------------------------------------------------------------------------
      ; Iterate through the list of errors
      ;--------------------------------------------------------------------------------------------
      
      ForEach Error()
        
        WriteStringN(LogFileId.i, FormatField("Time:",     18) + Error()\ErrorTime     + ", ")
        
        WriteString(LogFileId.i,  FormatField("Module:",   18) + Error()\ErrorModule   + ", ")
        
        WriteString(LogFileId.i,  FormatField("Message:",  18) + Error()\ErrorMessage  + ", ")
        
        WriteString(LogFileId.i,  FormatField("Message:",  18) + Error()\ExtraInfo)
        
      Next
      
      ;--------------------------------------------------------------------------------------------
      ; Close the error log
      ;--------------------------------------------------------------------------------------------
      
      CloseFile(LogFileId.i)
      
      ;--------------------------------------------------------------------------------------------
      ; Clear the list to start again
      ;--------------------------------------------------------------------------------------------
      
      ClearList(Error())
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      ; SetInfoBarArea("Headings", "Error",  "We could not get a file id so we should exit now", #PB_Compiler_Procedure)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ;
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    AddElement(Error())
    
    Error()\ErrorTime     = FormatDate("%hh:%ii:%ss", Date())
    
    Error()\ErrorModule   = ModuleName.s
    
    Error()\ErrorMessage  = Message.s
    
    Error()\ExtraInfo     = ExtraInfo.s
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ;
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 156
; FirstLine = 111
; Folding = -
; EnableXP