﻿;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; Try to open the system database and create missing tables
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Procedure OpenSystemDatabase()
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  FileHandle.i = OpenFile(#PB_Any, Program\DatabaseName)
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  If FileHandle.i
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    CloseFile(FileHandle.i)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    Program\DatabaseHandle = OpenDatabase(#PB_Any, Program\DatabaseName, #Empty$, #Empty$)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If Program\DatabaseHandle
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      VacuumUpdate.s = "PRAGMA auto_vacuum = on"
      
      ;--------------------------------------------------------------------------------------------
      ; Turn on auto database vacuum
      ;--------------------------------------------------------------------------------------------
      
      If DatabaseUpdate(Program\DatabaseHandle, VacuumUpdate.s) = #DatabaseUpdateFail
        
        MessageRequester("Vacuum setup error", "Could not setup auto database vacuum.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the update needed table out
      ;--------------------------------------------------------------------------------------------
      
      TableupdateCreate.s                         + 

      "CREATE TABLE IF NOT EXISTS Tableupdate("   + 
      
      "Category TEXT, "                           + 
      
      "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      
      If DatabaseUpdate(Program\DatabaseHandle, TableupdateCreate.s)  <> #DatabaseUpdateFail
        
        If CountRecords("Record", "Tableupdate") = "0"
          
          TableInsert.s              + 

          "INSERT INTO Tableupdate(" + 
          
          "Category) "               + 
          
          "VALUES('0')"
          
          If DatabaseUpdate(Program\DatabaseHandle, TableInsert.s) <> #DatabaseUpdateFail
            
            ; Database table update worked
            
          Else
            
            MessageRequester("Table insert error", "Could not add data to Tableupdate table in database.")
            
          EndIf
          
        EndIf
        
        ; The database table already exists or was not created for some reason
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the appointments table out
      ;--------------------------------------------------------------------------------------------
      
      VersionCreate.s                         + 

      "CREATE TABLE IF NOT EXISTS Version("   + 
      
      "ProgramName TEXT, "                    + 
      
      "VersionNumber TEXT, "                  + 
      
      "CreatedOn TEXT, "                      + 
      
      "LastUpdate TEXT, "                     + 
      
      "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      
      If DatabaseUpdate(Program\DatabaseHandle, VersionCreate.s) <>  #DatabaseUpdateFail
        
        If CountRecords("Record", "Version") = "0"
          
          VersionInsert.s                   + 

          "INSERT INTO Version("            + 
          
          "ProgramName, "                   + 
          
          "VersionNumber, "                 + 
          
          "CreatedOn, "                     + 
          
          "LastUpdate) "                    + 
          
          "VALUES("                         + 
          
          "'" + Trim(#Basename)             + 

          "', "                             + 

          "'" + Trim(#Version)              + 

          "', "                             + 

          "'"                               + 

          FormatDate("%yyyy%mm%dd", Date()) + 

          "', "                             +

          "'"                               + 

          FormatDate("%yyyy%mm%dd", Date()) + 

          "')"
          
          If DatabaseUpdate(Program\DatabaseHandle, VersionInsert.s) = #DatabaseUpdateFail
            
            MessageRequester("Table insert error", "Could not add data to version table in database.")
            
          EndIf
          
        EndIf
        
      Else
        
        ; The database table already exists or was not created for some reason
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the Keeper table out
      ;--------------------------------------------------------------------------------------------
      
      KeeperCreate.s                        + 

      "CREATE TABLE IF NOT EXISTS Keeper("  + 

      "Title TEXT, "                        + 

      "Information TEXT, "                  + 

      "Category TEXT, "                     + 

      "Archived TEXT, "                     + 

      "Favourite TEXT, "                    + 

      "Locked TEXT, "                       + 

      "Deleted TEXT, "                      + 

      "Updated TEXT, "                      + 

      "Owner TEXT, "                        + 

      "Attachments TEXT, "                  + 

      "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      
      If DatabaseUpdate(Program\DatabaseHandle, KeeperCreate.s) <> #DatabaseUpdateFail
        
      Else
        
        MessageRequester("Table creation error", "Could not create Keeper table in database.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the Archive table out
      ;--------------------------------------------------------------------------------------------
      
      ArchiveCreate.s                       + 

      "CREATE TABLE IF NOT EXISTS Archive(" + 

      "Title TEXT, "                        + 

      "Information TEXT, "                  + 

      "Category TEXT, "                     + 

      "Archived TEXT, "                     + 

      "Favourite TEXT, "                    + 

      "Locked TEXT, "                       + 

      "Deleted TEXT, "                      + 

      "Updated TEXT, "                      + 

      "Owner TEXT, "                        + 

      "Attachments TEXT, "                  + 

      "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      
      If DatabaseUpdate(Program\DatabaseHandle, ArchiveCreate.s) <> #DatabaseUpdateFail
        
      Else
        
        MessageRequester("Table creation error", "Could not create Keeper table in database.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      IndexCreate.s = "CREATE INDEX IF NOT EXISTS Keeperindex ON Keeper(Title)"

      If DatabaseUpdate(Program\DatabaseHandle, IndexCreate.s) <> #DatabaseUpdateFail
        
      Else
        
        ; The database table already exists or was not created for some reason
        
        MessageRequester("Table creation error", "Could not create Keeper index in database.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the Categories table out
      ;--------------------------------------------------------------------------------------------
      
      CategoryCreate.s                              + 

      "CREATE TABLE IF NOT EXISTS Categories("      + 

      "Category TEXT, "                             + 

      "Itemcount TEXT, "                            + 

      "Iconname TEXT, "                             + 

      "Record INTEGER PRIMARY KEY AUTOINCREMENT, "  + 

      "UNIQUE(Category))"
      
      If DatabaseUpdate(Program\DatabaseHandle, CategoryCreate.s) <> #DatabaseUpdateFail
        
      Else
        
        MessageRequester("Table creation error", "Could not create Categories table in database.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the Owners table out
      ;--------------------------------------------------------------------------------------------
      
      OwnerCreate.s                                 + 

      "CREATE TABLE IF NOT EXISTS Owners("          + 

      "Owner TEXT, "                                + 

      "Itemcount TEXT, "                            + 

      "Iconname TEXT, "                             + 

      "Record INTEGER PRIMARY KEY AUTOINCREMENT, "  + 

      "UNIQUE(Owner))"
      
      If DatabaseUpdate(Program\DatabaseHandle, OwnerCreate.s)  <> #DatabaseUpdateFail
        
      Else
        
        MessageRequester("Table creation error", "Could not create Owners table in database.")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Home number, work number, email address, home page, fax number, telex number, pager number
      ;--------------------------------------------------------------------------------------------
      
      AttachmentsCreate.s                                 + 

      "CREATE TABLE IF NOT EXISTS Attachments("           + 

      "Attachmentid INTEGER PRIMARY KEY AUTOINCREMENT, "  + 

      "Attachment BLOB, "                                 + 

      "Filename TEXT, "                                   + 

      "Record INTEGER, "                                  + 

      "FOREIGN KEY(Record) REFERENCES Keeper(Record))"
      
      If DatabaseUpdate(Program\DatabaseHandle, AttachmentsCreate.s) <> #DatabaseUpdateFail
        
      Else
        
        ; The database table already exists or was not created for some reason
        
      EndIf

      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      PreferencesCreate.s                         + 

      "CREATE TABLE IF NOT EXISTS Preferences("   + 

      "MD5FingerPrint TEXT, "                     + 

      "SearchLimit TEXT, "                        + 

      "LastSearch TEXT, "                         + 

      "BalloonTooltips TEXT, "                    + 

      "ColourBand TEXT, "                         + 

      "HideDetail TEXT, "                         + 

      "MessageSave TEXT, "                        + 
      
      "ShowToolbar TEXT, "                        + 

      "ScreenSnap TEXT, "                         + 

      "StickyWindow TEXT, "                       + 

      "TitleClock TEXT, "                         + 

      "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      
      If DatabaseUpdate(Program\DatabaseHandle, PreferencesCreate.s) <> #DatabaseUpdateFail
        
        If CountRecords("Record", "Preferences") = "0"
          
          PreferencesInsert.s         + 

          "INSERT INTO Preferences("  + 

          "MD5FingerPrint, "          + 

          "SearchLimit, "             + 

          "LastSearch, "              + 

          "BalloonTooltips, "         + 

          "ColourBand, "              + 

          "HideDetail, "              + 

          "MessageSave, "             + 
          
          "ShowToolbar, "             + 

          "ScreenSnap, "              + 

          "StickyWindow, "            + 

          "TitleClock) "              + 

          "VALUES("                   + 

          "'', "                      + ; MD5FingerPrint

          "'28', "                    + ; SearchLimit

          "'', "                      + ; LastSearch

          "'1', "                     + ; BalloonTooltips

          "'1', "                     + ; ColourBand

          "'0', "                     + ; HideDetail

          "'1', "                     + ; MessageSave

          "'1', "                     + ; ShowToolbar

          "'1', "                     + ; ScreenSnap

          "'1', "                     + ; StickyWindow

          "'1')"                        ; TitleClock

          If DatabaseUpdate(Program\DatabaseHandle, PreferencesInsert.s) <> #DatabaseUpdateFail
            
          Else
            
            ; The database table already exists or was not created for some reason
            
          EndIf
          
        EndIf
        
      Else
        
        MessageRequester("Table creation error", "Could not create preferences table in database.")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      MessageRequester("Database open error", "There was a serious problem attempting to connect to the system database. Could be corrupt or open by some other process. Exit Hive and try again.", #PB_MessageRequester_Ok)
      
      ProcedureReturn
      
    EndIf 
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    MessageRequester("Database file open error", "Could not open or create raw database file.", #PB_MessageRequester_Ok)
    
    ProcedureReturn
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.62 (Windows - x86)
; CursorPosition = 410
; FirstLine = 411
; Folding = -
; EnableXP
; HideErrorLog
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0