﻿;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; 
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Procedure AddNewData()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if a previous window is open
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> #True
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data window
    ;----------------------------------------------------------------------------------------------
    
    If Window_Data()
      
      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_Keeper, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; Warn other components a window is open and not to attempt to open another
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = #True
      
      ;--------------------------------------------------------------------------------------------
      ; Add keyboard shortcuts as backup to the buttons, Good for people with sore mouse wrists
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_SaveData,         #KeyboardShortcut_SaveData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_ExportData,       #KeyboardShortcut_ExportData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_ImportData,       #KeyboardShortcut_ImportData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_HelpData,         #KeyboardShortcut_HelpData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_ExitData,         #KeyboardShortcut_ExitData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_EscapeData,       #KeyboardShortcut_EscapeData)
      
      AddKeyboardShortcut(#Window_Data, #ShortcutValue_SearchData,       #KeyboardShortcut_SearchData)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the hover enabled images
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_Data_SaveData))
      
      AddHoverGadget(GadgetID(#Gadget_Data_ExportData))
      
      AddHoverGadget(GadgetID(#Gadget_Data_ImportData))
      
      AddHoverGadget(GadgetID(#Gadget_Data_HelpData))
      
      AddHoverGadget(GadgetID(#Gadget_Data_ExitData))
      
      ;--------------------------------------------------------------------------------------------
      ; Remove theme support from the comment box or it retains a border even when API removed
      ;--------------------------------------------------------------------------------------------
      
      RemoveBorders(#Gadget_Data_Details)
      
      ;--------------------------------------------------------------------------------------------
      ; Get the last record number in the database and give the next probable record number
      ;--------------------------------------------------------------------------------------------
      
      NextRecord.i = Val(LastRecord("Keeper", "Record")) + 1
      
      ;--------------------------------------------------------------------------------------------
      ; Use the common message as a window identifier
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = "Add New Keeper Item"
      
      ;--------------------------------------------------------------------------------------------
      ; Set the window title with the common message and next record number
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_Data, Program\LastWindow + "   --   Record number: " + Str(NextRecord.i) + " ?")
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillComboBoxImage(#Gadget_Data_cCategory, "SELECT Category, Iconname FROM Categories ORDER BY Category", Program\CategoryIcons, #Image_ListNocategory)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillComboBoxImage(#Gadget_Data_Owner, "SELECT Owner, Iconname FROM Owners ORDER BY Owner", Program\OwnerIcons, #Image_ListNoowner)
      
      ;--------------------------------------------------------------------------------------------
      ; Set initial search cue font
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetFont(#Gadget_Data_Finddata, FontID(Cue\SearchCueFont))
      
      ;--------------------------------------------------------------------------------------------
      ; Limit the number of search box characters and set the cue banner text. These variables are 
      ; set in the Keeper_Myconstants file.
      ;--------------------------------------------------------------------------------------------
      
      SendMessage_(GadgetID(#Gadget_Data_Finddata), #EM_SETLIMITTEXT, 67, 0)
      SendMessage_(GadgetID(#Gadget_Data_Finddata), #EM_SETCUEBANNER,  1,  Cue\SearchCueText)
      
      ;--------------------------------------------------------------------------------------------
      ; Set the current operation details on the the main window status bar
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_Data_Recordnumber,  Str(NextRecord.i) + " ?")
      
      ;--------------------------------------------------------------------------------------------
      ; Disable the favourite icon in a new record as it isn't set here
      ;--------------------------------------------------------------------------------------------
      
      HideGadget(#Gadget_Data_Status, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; Set the current operation details on the the main window status bar
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings",  "Info",  Program\LastWindow + "   --   Record number: " + Str(NextRecord.i) + " ?", #PB_Compiler_Procedure)
      
      ;--------------------------------------------------------------------------------------------
      ; Set focus on the appointment name field
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_Data_Title)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      HideWindow(#Window_Data, #False)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings",  "Error",  "Could not open the [" + Program\LastWindow + "] window.", #PB_Compiler_Procedure)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Warn",  "The [" +  Program\LastWindow + "] window is still open, close that one first.", #PB_Compiler_Procedure)
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.62 (Windows - x86)
; CursorPosition = 113
; FirstLine = 81
; Folding = -
; EnableXP
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0