﻿;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; Export appointment data to a standard XML file
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Procedure ExportDatabase()

  ;------------------------------------------------------------------------------------------------
  ; Process the current table name and dump the contents to an XML file on disk
  ;------------------------------------------------------------------------------------------------
  
  QueryString.s = "SELECT * FROM Keeper"
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  If DatabaseQuery(Program\DatabaseHandle,  QueryString.s)  <> #DatabaseQueryFail
    
    ;----------------------------------------------------------------------------------------------
    ; Process the next returned row
    ;----------------------------------------------------------------------------------------------
    
    While NextDatabaseRow(Program\DatabaseHandle)
      
      ;--------------------------------------------------------------------------------------------
      ; Have we created this XML tree already?
      ;--------------------------------------------------------------------------------------------
      
      If *XmlTree = #False
        
        *XmlTree = CreateXML(#PB_Any)                                                               ; Creates a new empty XML tree identified by the #XML number
        
        CompilerIf #PB_Compiler_Version > 524                                                      ; Compiler version greater than 5.24
          
          *RootXmlNode = CreateXMLNode(RootXMLNode(*XmlTree), #Empty$)                              ; Creates a new XML node and inserts it into the given parent node. 
          
        CompilerElse
  
          *RootXmlNode = CreateXMLNode(RootXMLNode(*XmlTree))                                       ; Creates a new XML node and inserts it into the given parent node. 
          
        CompilerEndIf
        
        SetXMLNodeName(*RootXmlNode, #Program)                                                      ; Changes the tagname of the given XML node (root in this case)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Creates a new XML node and inserts it into main XML node of the tree.
      ;--------------------------------------------------------------------------------------------
      
      CompilerIf #PB_Compiler_Version > 524   ; Compiler version greater than 5.24
        
        *RowNode = CreateXMLNode(MainXMLNode(*XmlTree), #Empty$)
      
      CompilerElse
      
        *RowNode = CreateXMLNode(MainXMLNode(*XmlTree))
      
      CompilerEndIf
    
      ;--------------------------------------------------------------------------------------------
      ; If the main node was created, dump all the columns using the column names as node names
      ;--------------------------------------------------------------------------------------------
      
      If *RowNode
        
        ;------------------------------------------------------------------------------------------
        ; Get the column names and write them first
        ;------------------------------------------------------------------------------------------
        
        NumberOfColumns.i = DatabaseColumns(Program\DatabaseHandle)
        
        ;------------------------------------------------------------------------------------------
        ; Iterate through the columns
        ;------------------------------------------------------------------------------------------
        
        For ColumnNamesLoop.i = 0 To NumberOfColumns.i -1
          
          CurrentColumn.s = DatabaseColumnName(Program\DatabaseHandle, ColumnNamesLoop.i)
          
          CompilerIf #PB_Compiler_Version > 524                                                     ; Compiler version greater than 5.24
            
            *ColumnNode = CreateXMLNode(*RowNode, #Empty$)                                           ; Creates a new XML node and inserts it into main XML node of the tree.
          
          CompilerElse
            
            *ColumnNode = CreateXMLNode(*RowNode)                                                    ; Creates a new XML node and inserts it into main XML node of the tree.
            
          CompilerEndIf
          
          SetXMLNodeText(*ColumnNode, TextToXml(GetDatabaseString(Program\DatabaseHandle,  ColumnNamesLoop.i)))
          
        Next                                                                                        ; Next column
        
        ;------------------------------------------------------------------------------------------
        ; Main node wasn't created, exit out of this procedure
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings",  "Error",  "Could not create the export data file.", #PB_Compiler_Procedure)
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Wend
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    FinishDatabaseQuery(Program\DatabaseHandle)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If *XmlTree
      
      FormatXML(*XmlTree, #PB_XML_ReFormat)
      
      SaveXML(*XmlTree, Program\BackupDirectory + #Program + "_Export.xml")
      
      FreeXML(*XmlTree)
      
      SetInfoBarArea("Headings",  "Info",  "Data exported to " + Program\BackupDirectory, #PB_Compiler_Procedure)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; The database query has failed for some reason
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Error",  "The database query failed or was empty. " + DatabaseError(), #PB_Compiler_Procedure)
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  TextFileId.i = CreateFile(#PB_Any, Program\BackupDirectory + #Program + "_Export.txt")
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  If TextFileId.i <> #NoExportFileHandle
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If DatabaseQuery(Program\DatabaseHandle,  "SELECT Title, Information FROM Keeper")  <> #DatabaseQueryFail
      
      While NextDatabaseRow(Program\DatabaseHandle)
        
        TitleString.s       = KillQuote(GetDatabaseString(Program\DatabaseHandle, 0))
        
        InformationString.s = KillQuote(GetDatabaseString(Program\DatabaseHandle, 1))
        
        WriteStringN(TextFileId.i, "Title: " + TitleString.s)
        
        WriteStringN(TextFileId.i, #Empty$)
        
        WriteStringN(TextFileId.i, "Info:  " + InformationString.s)
        
        WriteStringN(TextFileId.i, #Empty$)
        
        WriteStringN(TextFileId.i, #Empty$)
        
        WriteStringN(TextFileId.i, "___________________::: End Of Record ::: __________________")
        
        WriteStringN(TextFileId.i, #Empty$)
        
      Wend
      
      FinishDatabaseQuery(Program\DatabaseHandle)
      
      MessageString.s = "Keeper XML data and text files have been saved in this directory:" + #CRLF$ + #CRLF$
      
      MessageString.s + Program\BackupDirectory

      MessageRequester("Export finished", MessageString.s)

    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    CloseFile(TextFileId)  
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------

EndProcedure


; IDE Options = PureBasic 5.62 (Windows - x86)
; CursorPosition = 182
; FirstLine = 156
; Folding = -
; EnableXP
; HideErrorLog
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0