﻿;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; Search Keeper's database with advanced SQL tools and limits
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Procedure AdvancedSearch()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if an existing window is opened
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> #True
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data form window
    ;----------------------------------------------------------------------------------------------
    
    If Window_Search()
      
      ;--------------------------------------------------------------------------------------------
      ; Window was opened so set mutex to prevent other windows from opening
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = #True
      
      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_Keeper, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      StickyWindow(#Window_Search, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTheme_(GadgetID(#Gadget_Search_oSortAcending),       @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_oSortDescending),     @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_cbQueryReturnLimit),  @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_sQueryReturnLimit),   @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_cbCheckEnter),        @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_oCheckOr),            @null.w, @null.w)
      
      SetWindowTheme_(GadgetID(#Gadget_Search_oCheckAnd),           @null.w, @null.w)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_Search, #ShortcutValue_RunSearch,      #KeyboardShortCut_RunSearch)
      
      AddKeyboardShortcut(#Window_Search, #ShortcutValue_ReturnSearch,   #KeyboardShortcut_ReturnSearch)
      
      AddKeyboardShortcut(#Window_Search, #ShortcutValue_HelpSearch,     #KeyboardShortcut_HelpSearch)
      
      AddKeyboardShortcut(#Window_Search, #ShortcutValue_ExitSearch,     #KeyboardShortcut_ExitSearch)
      
      AddKeyboardShortcut(#Window_Search, #ShortcutValue_EscapeSearch,   #KeyboardShortcut_EscapeSearch)
      
      ;--------------------------------------------------------------------------------------------
      ; Setup the form hover controls
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_Search_RunSearch))
      
      AddHoverGadget(GadgetID(#Gadget_Search_HelpSearch))
      
      AddHoverGadget(GadgetID(#Gadget_Search_ExitSearch))

      ;--------------------------------------------------------------------------------------------
      ; Set the last window message for the closure routine later
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = "Search passwords, advanced mode."
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the data window
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_Search, Program\LastWindow)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the Search type operators
      ;--------------------------------------------------------------------------------------------
      
      Restore BeginSearchTypes
      
      While TempString.s <> "_EndSearchTypes_"
        
        Read.s TempString.s
        
        If TempString.s <> "_EndSearchTypes_"
          
          AddGadgetItem(#Gadget_Search_SearchType, -1, TempString.s)
          
        EndIf
        
      Wend
      
      TempString.s = "<>"
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      If Program\SearchWindowSearchType
        
        SetGadgetState(#Gadget_Search_SearchType,   Program\SearchWindowSearchType)
        
      Else
        
        SetGadgetState(#Gadget_Search_SearchType,   #FirstItem)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Add the Search type operators
      ;--------------------------------------------------------------------------------------------
      
      AddGadgetItem(#Gadget_Search_SearchField, #AtTheEndOfTheList, "All fields")
      
      Restore BeginSqlFields
      
      While TempString.s <> "_EndSqlFields_"
        
        Read.s TempString.s
        
        If TempString.s <> "_EndSqlFields_"
          
          AddGadgetItem(#Gadget_Search_SearchField, -1, TempString.s)
          
        EndIf
        
      Wend
      
      TempString.s = "<>"
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      If Program\SearchWindowSearchField
        
        SetGadgetState(#Gadget_Search_SearchField,  Program\SearchWindowSearchField)
        
      Else
        
        SetGadgetState(#Gadget_Search_SearchField,  #FirstItem)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Set the last sort text to the window
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_Search_SearchText,    Program\SearchWindowSearchText)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SendMessage_(GadgetID(#Gadget_Search_SearchText), #EM_SETSEL, Len(Program\SearchWindowSearchText), Len(Program\SearchWindowSearchText))
      
      ;--------------------------------------------------------------------------------------------
      ; Add the available sort fields
      ;--------------------------------------------------------------------------------------------
      
      Restore BeginSqlFields
      
      While TempString.s <> "_EndSqlFields_"
        
        Read.s TempString.s
        
        If TempString.s <> "_EndSqlFields_" And TempString.s <> "All fields"
          
          AddGadgetItem(#Gadget_Search_SortField, -1, TempString.s)
          
        EndIf
        
      Wend
      
      TempString.s = "<>"
      
      ;--------------------------------------------------------------------------------------------
      ; Set the default field to sort on
      ;--------------------------------------------------------------------------------------------
      
      If Program\SearchWindowSortField
        
        SetGadgetState(#Gadget_Search_SortField,  Program\SearchWindowSortField)
        
      Else
        
        SetGadgetState(#Gadget_Search_SortField,  #FirstItem)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Set the default sort direction
      ;--------------------------------------------------------------------------------------------
      
      If Program\SearchWindowSortDirection = #False
        
        SetGadgetState(#Gadget_Search_oSortAcending, #True)  
        
      ElseIf Program\SearchWindowSortDirection = #True
        
        SetGadgetState(#Gadget_Search_oSortDescending, #True)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Set the checkbox to turn on or off recipe number limiting during searches
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Search_cbQueryReturnLimit, Program\SearchWindowQueryReturnLimit)
      
      ;--------------------------------------------------------------------------------------------
      ; Set the number of recipes to return during a search
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Search_sQueryReturnLimit,      Program\SearchWindowQueryReturnSize)
      
      SetGadgetText(#Gadget_Search_sQueryReturnLimit,   Str(Program\SearchWindowQueryReturnSize))
      
      ;--------------------------------------------------------------------------------------------
      ; Set the close mode for the window
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Search_cbCheckEnter,       Program\SearchWindowCloseMode)
      
      ;--------------------------------------------------------------------------------------------
      ; Set the multiple search parameters if any
      ;--------------------------------------------------------------------------------------------
      
      If Program\SearchWindowSearchMode = #False
        
        SetGadgetState(#Gadget_Search_oCheckOr, #True)
        
      ElseIf Program\SearchWindowSearchMode = #True
        
        SetGadgetState(#Gadget_Search_oCheckAnd, #True)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Show information in the statusbar area
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings", "Info", Program\LastWindow, #PB_Compiler_Procedure)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the data form window is topmost
      ;--------------------------------------------------------------------------------------------
      
      SetActiveWindow(#Window_Search)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the version field is selected
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_Search_SearchText)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings", "Error", "The program window could not be opened.", #PB_Compiler_Procedure)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Warn", "Another program window is still open.", #pb_compiler_procedure)
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.62 (Windows - x86)
; CursorPosition = 290
; FirstLine = 254
; Folding = -
; EnableXP
; HideErrorLog
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0